{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.BusinessAudience where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Audience

-- | A set of characteristics belonging to businesses, e.g. who compose an item's target audience.
--
--   [@id@] BusinessAudience
--
--   [@label@] Business Audience
--
--   [@comment@] A set of characteristics belonging to businesses, e.g. who compose an item's target audience.
--
--   [@ancestors@] @'Thing','Intangible','Audience'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Audience'@
--
--   [@url@] <http://schema.org/BusinessAudience>
data BusinessAudience = BusinessAudience { numberOfEmployees :: NumberOfEmployees
                                         , yearlyRevenue :: YearlyRevenue
                                         , yearsInOperation :: YearsInOperation
                                         , audienceType :: AudienceType
                                         , geographicArea :: GeographicArea
                                         , additionalType :: AdditionalType
                                         , alternateName :: AlternateName
                                         , description :: Description
                                         , image :: Image
                                         , mainEntityOfPage :: MainEntityOfPage
                                         , name :: Name
                                         , potentialAction :: PotentialAction
                                         , sameAs :: SameAs
                                         , url :: Url
                                         }
                        deriving (Show, Read, Eq, Typeable)

instance MetaData BusinessAudience where
  _label         = const "Business Audience"
  _comment_plain = const "A set of characteristics belonging to businesses, e.g. who compose an item's target audience."
  _comment       = const "A set of characteristics belonging to businesses, e.g. who compose an item's target audience."
  _url           = const "http://schema.org/BusinessAudience"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Audience.Audience)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Audience.Audience)]