{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Canal where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Landform
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BodyOfWater

-- | A canal, like the Panama Canal.
--
--   [@id@] Canal
--
--   [@label@] Canal
--
--   [@comment@] A canal, like the Panama Canal.
--
--   [@ancestors@] @'Thing','Place','Landform','BodyOfWater'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'BodyOfWater'@
--
--   [@url@] <http://schema.org/Canal>
data Canal = Canal { additionalProperty :: AdditionalProperty
                   , address :: Address
                   , aggregateRating :: AggregateRating
                   , branchCode :: BranchCode
                   , containedInPlace :: ContainedInPlace
                   , containsPlace :: ContainsPlace
                   , event :: Event
                   , faxNumber :: FaxNumber
                   , geo :: Geo
                   , globalLocationNumber :: GlobalLocationNumber
                   , hasMap :: HasMap
                   , isicV4 :: IsicV4
                   , logo :: Logo
                   , openingHoursSpecification :: OpeningHoursSpecification
                   , photo :: Photo
                   , review :: Review
                   , telephone :: Telephone
                   , additionalType :: AdditionalType
                   , alternateName :: AlternateName
                   , description :: Description
                   , image :: Image
                   , mainEntityOfPage :: MainEntityOfPage
                   , name :: Name
                   , potentialAction :: PotentialAction
                   , sameAs :: SameAs
                   , url :: Url
                   }
             deriving (Show, Read, Eq, Typeable)

instance MetaData Canal where
  _label         = const "Canal"
  _comment_plain = const "A canal, like the Panama Canal."
  _comment       = const "A canal, like the Panama Canal."
  _url           = const "http://schema.org/Canal"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Landform.Landform)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.BodyOfWater.BodyOfWater)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BodyOfWater.BodyOfWater)]