{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.CookAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CreateAction

-- | The act of producing/preparing food.
--
--   [@id@] CookAction
--
--   [@label@] Cook Action
--
--   [@comment@] The act of producing/preparing food.
--
--   [@ancestors@] @'Thing','Action','CreateAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'CreateAction'@
--
--   [@url@] <http://schema.org/CookAction>
data CookAction = CookAction { foodEstablishment :: FoodEstablishment
                             , foodEvent :: FoodEvent
                             , recipe :: Recipe
                             , actionStatus :: ActionStatus
                             , agent :: Agent
                             , endTime :: EndTime
                             , error :: Error
                             , instrument :: Instrument
                             , location :: Location
                             , object :: Object
                             , participant :: Participant
                             , result :: Result
                             , startTime :: StartTime
                             , target :: Target
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData CookAction where
  _label         = const "Cook Action"
  _comment_plain = const "The act of producing/preparing food."
  _comment       = const "The act of producing/preparing food."
  _url           = const "http://schema.org/CookAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreateAction.CreateAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CreateAction.CreateAction)]