{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DepartmentStore where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Store
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DepartmentStore
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place

-- | A department store.
--
--   [@id@] DepartmentStore
--
--   [@label@] Department Store
--
--   [@comment@] A department store.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','Store','DepartmentStore','Thing','Place','LocalBusiness','Store'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Store'@
--
--   [@url@] <http://schema.org/DepartmentStore>
data DepartmentStore = DepartmentStore { branchCode :: BranchCode
                                       , currenciesAccepted :: CurrenciesAccepted
                                       , openingHours :: OpeningHours
                                       , paymentAccepted :: PaymentAccepted
                                       , priceRange :: PriceRange
                                       , address :: Address
                                       , aggregateRating :: AggregateRating
                                       , alumni :: Alumni
                                       , areaServed :: AreaServed
                                       , award :: Award
                                       , brand :: Brand
                                       , contactPoint :: ContactPoint
                                       , department :: Department
                                       , dissolutionDate :: DissolutionDate
                                       , duns :: Duns
                                       , email :: Email
                                       , employee :: Employee
                                       , event :: Event
                                       , faxNumber :: FaxNumber
                                       , founder :: Founder
                                       , foundingDate :: FoundingDate
                                       , foundingLocation :: FoundingLocation
                                       , globalLocationNumber :: GlobalLocationNumber
                                       , hasOfferCatalog :: HasOfferCatalog
                                       , hasPOS :: HasPOS
                                       , isicV4 :: IsicV4
                                       , legalName :: LegalName
                                       , location :: Location
                                       , logo :: Logo
                                       , makesOffer :: MakesOffer
                                       , member :: Member
                                       , memberOf :: MemberOf
                                       , naics :: Naics
                                       , numberOfEmployees :: NumberOfEmployees
                                       , owns :: Owns
                                       , parentOrganization :: ParentOrganization
                                       , review :: Review
                                       , seeks :: Seeks
                                       , subOrganization :: SubOrganization
                                       , taxID :: TaxID
                                       , telephone :: Telephone
                                       , vatID :: VatID
                                       , additionalProperty :: AdditionalProperty
                                       , containedInPlace :: ContainedInPlace
                                       , containsPlace :: ContainsPlace
                                       , geo :: Geo
                                       , hasMap :: HasMap
                                       , openingHoursSpecification :: OpeningHoursSpecification
                                       , photo :: Photo
                                       , additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData DepartmentStore where
  _label         = const "Department Store"
  _comment_plain = const "A department store."
  _comment       = const "A department store."
  _url           = const "http://schema.org/DepartmentStore"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Store.Store)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DepartmentStore.DepartmentStore)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Store.Store)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Store.Store)]