{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DoseSchedule where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type hiding (DoseSchedule)
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalIntangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MaximumDoseSchedule
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RecommendedDoseSchedule
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ReportedDoseSchedule

-- | A specific dosing schedule for a drug or supplement.
--
--   [@id@] DoseSchedule
--
--   [@label@] Dose Schedule
--
--   [@comment@] A specific dosing schedule for a drug or supplement.
--
--   [@ancestors@] @'Thing','MedicalEntity','MedicalIntangible'@
--
--   [@subtypes@] @'MaximumDoseSchedule','RecommendedDoseSchedule','ReportedDoseSchedule'@
--
--   [@supertypes@] @'MedicalIntangible'@
--
--   [@url@] <http://schema.org/DoseSchedule>
data DoseSchedule = DoseSchedule { doseUnit :: DoseUnit
                                 , doseValue :: DoseValue
                                 , frequency :: Frequency
                                 , targetPopulation :: TargetPopulation
                                 , code :: Code
                                 , guideline :: Guideline
                                 , medicineSystem :: MedicineSystem
                                 , recognizingAuthority :: RecognizingAuthority
                                 , relevantSpecialty :: RelevantSpecialty
                                 , study :: Study
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData DoseSchedule where
  _label         = const "Dose Schedule"
  _comment_plain = const "A specific dosing schedule for a drug or supplement."
  _comment       = const "A specific dosing schedule for a drug or supplement."
  _url           = const "http://schema.org/DoseSchedule"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIntangible.MedicalIntangible)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MaximumDoseSchedule.MaximumDoseSchedule)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RecommendedDoseSchedule.RecommendedDoseSchedule)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ReportedDoseSchedule.ReportedDoseSchedule)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIntangible.MedicalIntangible)]