{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.EducationalOrganization where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CollegeOrUniversity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ElementarySchool
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.HighSchool
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MiddleSchool
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Preschool
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.School

-- | An educational organization.
--
--   [@id@] EducationalOrganization
--
--   [@label@] Educational Organization
--
--   [@comment@] An educational organization.
--
--   [@ancestors@] @'Thing','Organization'@
--
--   [@subtypes@] @'CollegeOrUniversity','ElementarySchool','HighSchool','MiddleSchool','Preschool','School'@
--
--   [@supertypes@] @'Organization'@
--
--   [@url@] <http://schema.org/EducationalOrganization>
data EducationalOrganization = EducationalOrganization { alumni :: Alumni
                                                       , address :: Address
                                                       , aggregateRating :: AggregateRating
                                                       , areaServed :: AreaServed
                                                       , award :: Award
                                                       , brand :: Brand
                                                       , contactPoint :: ContactPoint
                                                       , department :: Department
                                                       , dissolutionDate :: DissolutionDate
                                                       , duns :: Duns
                                                       , email :: Email
                                                       , employee :: Employee
                                                       , event :: Event
                                                       , faxNumber :: FaxNumber
                                                       , founder :: Founder
                                                       , foundingDate :: FoundingDate
                                                       , foundingLocation :: FoundingLocation
                                                       , globalLocationNumber :: GlobalLocationNumber
                                                       , hasOfferCatalog :: HasOfferCatalog
                                                       , hasPOS :: HasPOS
                                                       , isicV4 :: IsicV4
                                                       , legalName :: LegalName
                                                       , location :: Location
                                                       , logo :: Logo
                                                       , makesOffer :: MakesOffer
                                                       , member :: Member
                                                       , memberOf :: MemberOf
                                                       , naics :: Naics
                                                       , numberOfEmployees :: NumberOfEmployees
                                                       , owns :: Owns
                                                       , parentOrganization :: ParentOrganization
                                                       , review :: Review
                                                       , seeks :: Seeks
                                                       , subOrganization :: SubOrganization
                                                       , taxID :: TaxID
                                                       , telephone :: Telephone
                                                       , vatID :: VatID
                                                       , additionalType :: AdditionalType
                                                       , alternateName :: AlternateName
                                                       , description :: Description
                                                       , image :: Image
                                                       , mainEntityOfPage :: MainEntityOfPage
                                                       , name :: Name
                                                       , potentialAction :: PotentialAction
                                                       , sameAs :: SameAs
                                                       , url :: Url
                                                       }
                               deriving (Show, Read, Eq, Typeable)

instance MetaData EducationalOrganization where
  _label         = const "Educational Organization"
  _comment_plain = const "An educational organization."
  _comment       = const "An educational organization."
  _url           = const "http://schema.org/EducationalOrganization"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CollegeOrUniversity.CollegeOrUniversity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ElementarySchool.ElementarySchool)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.HighSchool.HighSchool)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MiddleSchool.MiddleSchool)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Preschool.Preschool)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.School.School)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)]