{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.EmployeeRole where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Role
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OrganizationRole

-- | A subclass of OrganizationRole used to describe employee relationships.
--
--   [@id@] EmployeeRole
--
--   [@label@] Employee Role
--
--   [@comment@] A subclass of OrganizationRole used to describe employee relationships.
--
--   [@ancestors@] @'Thing','Intangible','Role','OrganizationRole'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'OrganizationRole'@
--
--   [@url@] <http://schema.org/EmployeeRole>
data EmployeeRole = EmployeeRole { baseSalary :: BaseSalary
                                 , salaryCurrency :: SalaryCurrency
                                 , numberedPosition :: NumberedPosition
                                 , endDate :: EndDate
                                 , roleName :: RoleName
                                 , startDate :: StartDate
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData EmployeeRole where
  _label         = const "Employee Role"
  _comment_plain = const "A subclass of OrganizationRole used to describe employee relationships."
  _comment       = const "A subclass of OrganizationRole used to describe employee relationships."
  _url           = const "http://schema.org/EmployeeRole"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Role.Role)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OrganizationRole.OrganizationRole)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.OrganizationRole.OrganizationRole)]