{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ExercisePlan where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type hiding (ExercisePlan)
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CreativeWork
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ExercisePlan
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalTherapy
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LifestyleModification
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PhysicalActivity

-- | Fitness-related activity designed for a specific health-related purpose, including defined exercise routines as well as activity prescribed by a clinician.
--
--   [@id@] ExercisePlan
--
--   [@label@] Exercise Plan
--
--   [@comment@] Fitness-related activity designed for a specific health-related purpose, including defined exercise routines as well as activity prescribed by a clinician.
--
--   [@ancestors@] @'Thing','CreativeWork','ExercisePlan','Thing','MedicalEntity','MedicalTherapy','LifestyleModification','PhysicalActivity'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'CreativeWork','PhysicalActivity'@
--
--   [@url@] <http://schema.org/ExercisePlan>
data ExercisePlan = ExercisePlan { activityDuration :: ActivityDuration
                                 , activityFrequency :: ActivityFrequency
                                 , additionalVariable :: AdditionalVariable
                                 , exerciseType :: ExerciseType
                                 , intensity :: Intensity
                                 , repetitions :: Repetitions
                                 , restPeriods :: RestPeriods
                                 , workload :: Workload
                                 , about :: About
                                 , accessibilityAPI :: AccessibilityAPI
                                 , accessibilityControl :: AccessibilityControl
                                 , accessibilityFeature :: AccessibilityFeature
                                 , accessibilityHazard :: AccessibilityHazard
                                 , accountablePerson :: AccountablePerson
                                 , aggregateRating :: AggregateRating
                                 , alternativeHeadline :: AlternativeHeadline
                                 , associatedMedia :: AssociatedMedia
                                 , audience :: Audience
                                 , audio :: Audio
                                 , author :: Author
                                 , award :: Award
                                 , character :: Character
                                 , citation :: Citation
                                 , comment :: Comment
                                 , commentCount :: CommentCount
                                 , contentLocation :: ContentLocation
                                 , contentRating :: ContentRating
                                 , contributor :: Contributor
                                 , copyrightHolder :: CopyrightHolder
                                 , copyrightYear :: CopyrightYear
                                 , creator :: Creator
                                 , dateCreated :: DateCreated
                                 , dateModified :: DateModified
                                 , datePublished :: DatePublished
                                 , discussionUrl :: DiscussionUrl
                                 , editor :: Editor
                                 , educationalAlignment :: EducationalAlignment
                                 , educationalUse :: EducationalUse
                                 , encoding :: Encoding
                                 , exampleOfWork :: ExampleOfWork
                                 , fileFormat :: FileFormat
                                 , genre :: Genre
                                 , hasPart :: HasPart
                                 , headline :: Headline
                                 , inLanguage :: InLanguage
                                 , interactionStatistic :: InteractionStatistic
                                 , interactivityType :: InteractivityType
                                 , isBasedOnUrl :: IsBasedOnUrl
                                 , isFamilyFriendly :: IsFamilyFriendly
                                 , isPartOf :: IsPartOf
                                 , keywords :: Keywords
                                 , learningResourceType :: LearningResourceType
                                 , license :: License
                                 , locationCreated :: LocationCreated
                                 , mainEntity :: MainEntity
                                 , mentions :: Mentions
                                 , offers :: Offers
                                 , position :: Position
                                 , producer :: Producer
                                 , provider :: Provider
                                 , publication :: Publication
                                 , publisher :: Publisher
                                 , publishingPrinciples :: PublishingPrinciples
                                 , recordedAt :: RecordedAt
                                 , releasedEvent :: ReleasedEvent
                                 , review :: Review
                                 , schemaVersion :: SchemaVersion
                                 , sourceOrganization :: SourceOrganization
                                 , text :: Text
                                 , thumbnailUrl :: ThumbnailUrl
                                 , timeRequired :: TimeRequired
                                 , translator :: Translator
                                 , typicalAgeRange :: TypicalAgeRange
                                 , version :: Version
                                 , video :: Video
                                 , workExample :: WorkExample
                                 , associatedAnatomy :: AssociatedAnatomy
                                 , category :: Category
                                 , epidemiology :: Epidemiology
                                 , pathophysiology :: Pathophysiology
                                 , adverseOutcome :: AdverseOutcome
                                 , contraindication :: Contraindication
                                 , duplicateTherapy :: DuplicateTherapy
                                 , indication :: Indication
                                 , seriousAdverseOutcome :: SeriousAdverseOutcome
                                 , code :: Code
                                 , guideline :: Guideline
                                 , medicineSystem :: MedicineSystem
                                 , recognizingAuthority :: RecognizingAuthority
                                 , relevantSpecialty :: RelevantSpecialty
                                 , study :: Study
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData ExercisePlan where
  _label         = const "Exercise Plan"
  _comment_plain = const "Fitness-related activity designed for a specific health-related purpose, including defined exercise routines as well as activity prescribed by a clinician."
  _comment       = const "Fitness-related activity designed for a specific health-related purpose, including defined exercise routines as well as activity prescribed by a clinician."
  _url           = const "http://schema.org/ExercisePlan"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ExercisePlan.ExercisePlan)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalTherapy.MedicalTherapy)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LifestyleModification.LifestyleModification)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PhysicalActivity.PhysicalActivity)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PhysicalActivity.PhysicalActivity)]