{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.LodgingReservation where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Reservation

-- | A reservation for lodging at a hotel, motel, inn, etc.
--
--   [@id@] LodgingReservation
--
--   [@label@] Lodging Reservation
--
--   [@comment@] A reservation for lodging at a hotel, motel, inn, etc.
--
--   [@ancestors@] @'Thing','Intangible','Reservation'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Reservation'@
--
--   [@url@] <http://schema.org/LodgingReservation>
data LodgingReservation = LodgingReservation { checkinTime :: CheckinTime
                                             , checkoutTime :: CheckoutTime
                                             , lodgingUnitDescription :: LodgingUnitDescription
                                             , lodgingUnitType :: LodgingUnitType
                                             , numAdults :: NumAdults
                                             , numChildren :: NumChildren
                                             , bookingTime :: BookingTime
                                             , broker :: Broker
                                             , modifiedTime :: ModifiedTime
                                             , priceCurrency :: PriceCurrency
                                             , programMembershipUsed :: ProgramMembershipUsed
                                             , provider :: Provider
                                             , reservationFor :: ReservationFor
                                             , reservationId :: ReservationId
                                             , reservationStatus :: ReservationStatus
                                             , reservedTicket :: ReservedTicket
                                             , totalPrice :: TotalPrice
                                             , underName :: UnderName
                                             , additionalType :: AdditionalType
                                             , alternateName :: AlternateName
                                             , description :: Description
                                             , image :: Image
                                             , mainEntityOfPage :: MainEntityOfPage
                                             , name :: Name
                                             , potentialAction :: PotentialAction
                                             , sameAs :: SameAs
                                             , url :: Url
                                             }
                          deriving (Show, Read, Eq, Typeable)

instance MetaData LodgingReservation where
  _label         = const "Lodging Reservation"
  _comment_plain = const "A reservation for lodging at a hotel, motel, inn, etc."
  _comment       = const "A reservation for lodging at a hotel, motel, inn, etc."
  _url           = const "http://schema.org/LodgingReservation"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Reservation.Reservation)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Reservation.Reservation)]