{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.OnDemandEvent where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Event
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PublicationEvent

-- | A publication event e.g. catch-up TV or radio podcast, during which a program is available on-demand.
--
--   [@id@] OnDemandEvent
--
--   [@label@] On Demand Event
--
--   [@comment@] A publication event e.g. catch-up TV or radio podcast, during which a program is available on-demand.
--
--   [@ancestors@] @'Thing','Event','PublicationEvent'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'PublicationEvent'@
--
--   [@url@] <http://schema.org/OnDemandEvent>
data OnDemandEvent = OnDemandEvent { isAccessibleForFree :: IsAccessibleForFree
                                   , publishedOn :: PublishedOn
                                   , aggregateRating :: AggregateRating
                                   , attendee :: Attendee
                                   , doorTime :: DoorTime
                                   , duration :: Duration
                                   , endDate :: EndDate
                                   , eventStatus :: EventStatus
                                   , inLanguage :: InLanguage
                                   , location :: Location
                                   , offers :: Offers
                                   , organizer :: Organizer
                                   , performer :: Performer
                                   , previousStartDate :: PreviousStartDate
                                   , recordedIn :: RecordedIn
                                   , review :: Review
                                   , startDate :: StartDate
                                   , subEvent :: SubEvent
                                   , superEvent :: SuperEvent
                                   , typicalAgeRange :: TypicalAgeRange
                                   , workFeatured :: WorkFeatured
                                   , workPerformed :: WorkPerformed
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData OnDemandEvent where
  _label         = const "On Demand Event"
  _comment_plain = const "A publication event e.g. catch-up TV or radio podcast, during which a program is available on-demand."
  _comment       = const "A publication event e.g. catch-up TV or radio podcast, during which a program is available on-demand."
  _url           = const "http://schema.org/OnDemandEvent"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Event.Event)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PublicationEvent.PublicationEvent)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.PublicationEvent.PublicationEvent)]