{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.PhysicalActivityCategory where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Enumeration
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEnumeration
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PhysicalActivityCategory
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalIntangible

-- | Categories of physical activity, organized by physiologic classification.
--
--   [@id@] PhysicalActivityCategory
--
--   [@label@] Physical Activity Category
--
--   [@comment@] Categories of physical activity, organized by physiologic classification.
--
--   [@ancestors@] @'Thing','Intangible','Enumeration','MedicalEnumeration','PhysicalActivityCategory','Thing','Intangible','Enumeration','PhysicalActivityCategory','Thing','MedicalEntity','MedicalIntangible','MedicalEnumeration'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Enumeration','MedicalEnumeration'@
--
--   [@url@] <http://schema.org/PhysicalActivityCategory>
data PhysicalActivityCategory = PhysicalActivityCategory { supersededBy :: SupersededBy
                                                         , code :: Code
                                                         , guideline :: Guideline
                                                         , medicineSystem :: MedicineSystem
                                                         , recognizingAuthority :: RecognizingAuthority
                                                         , relevantSpecialty :: RelevantSpecialty
                                                         , study :: Study
                                                         , additionalType :: AdditionalType
                                                         , alternateName :: AlternateName
                                                         , description :: Description
                                                         , image :: Image
                                                         , mainEntityOfPage :: MainEntityOfPage
                                                         , name :: Name
                                                         , potentialAction :: PotentialAction
                                                         , sameAs :: SameAs
                                                         , url :: Url
                                                         }
                                deriving (Show, Read, Eq, Typeable)

instance MetaData PhysicalActivityCategory where
  _label         = const "Physical Activity Category"
  _comment_plain = const "Categories of physical activity, organized by physiologic classification."
  _comment       = const "Categories of physical activity, organized by physiologic classification."
  _url           = const "http://schema.org/PhysicalActivityCategory"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PhysicalActivityCategory.PhysicalActivityCategory)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PhysicalActivityCategory.PhysicalActivityCategory)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIntangible.MedicalIntangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)]