{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.PlanAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OrganizeAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CancelAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ReserveAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ScheduleAction

-- | The act of planning the execution of an event/task/action/reservation/plan to a future date.
--
--   [@id@] PlanAction
--
--   [@label@] Plan Action
--
--   [@comment@] The act of planning the execution of an event/task/action/reservation/plan to a future date.
--
--   [@ancestors@] @'Thing','Action','OrganizeAction'@
--
--   [@subtypes@] @'CancelAction','ReserveAction','ScheduleAction'@
--
--   [@supertypes@] @'OrganizeAction'@
--
--   [@url@] <http://schema.org/PlanAction>
data PlanAction = PlanAction { scheduledTime :: ScheduledTime
                             , actionStatus :: ActionStatus
                             , agent :: Agent
                             , endTime :: EndTime
                             , error :: Error
                             , instrument :: Instrument
                             , location :: Location
                             , object :: Object
                             , participant :: Participant
                             , result :: Result
                             , startTime :: StartTime
                             , target :: Target
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData PlanAction where
  _label         = const "Plan Action"
  _comment_plain = const "The act of planning the execution of an event/task/action/reservation/plan to a future date."
  _comment       = const "The act of planning the execution of an event/task/action/reservation/plan to a future date."
  _url           = const "http://schema.org/PlanAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OrganizeAction.OrganizeAction)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CancelAction.CancelAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ReserveAction.ReserveAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ScheduleAction.ScheduleAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.OrganizeAction.OrganizeAction)]