{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.RadioEpisode where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CreativeWork
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Episode

-- | A radio episode which can be part of a series or season.
--
--   [@id@] RadioEpisode
--
--   [@label@] Radio Episode
--
--   [@comment@] A radio episode which can be part of a series or season.
--
--   [@ancestors@] @'Thing','CreativeWork','Episode'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Episode'@
--
--   [@url@] <http://schema.org/RadioEpisode>
data RadioEpisode = RadioEpisode { actor :: Actor
                                 , director :: Director
                                 , episodeNumber :: EpisodeNumber
                                 , musicBy :: MusicBy
                                 , partOfSeason :: PartOfSeason
                                 , partOfSeries :: PartOfSeries
                                 , productionCompany :: ProductionCompany
                                 , trailer :: Trailer
                                 , about :: About
                                 , accessibilityAPI :: AccessibilityAPI
                                 , accessibilityControl :: AccessibilityControl
                                 , accessibilityFeature :: AccessibilityFeature
                                 , accessibilityHazard :: AccessibilityHazard
                                 , accountablePerson :: AccountablePerson
                                 , aggregateRating :: AggregateRating
                                 , alternativeHeadline :: AlternativeHeadline
                                 , associatedMedia :: AssociatedMedia
                                 , audience :: Audience
                                 , audio :: Audio
                                 , author :: Author
                                 , award :: Award
                                 , character :: Character
                                 , citation :: Citation
                                 , comment :: Comment
                                 , commentCount :: CommentCount
                                 , contentLocation :: ContentLocation
                                 , contentRating :: ContentRating
                                 , contributor :: Contributor
                                 , copyrightHolder :: CopyrightHolder
                                 , copyrightYear :: CopyrightYear
                                 , creator :: Creator
                                 , dateCreated :: DateCreated
                                 , dateModified :: DateModified
                                 , datePublished :: DatePublished
                                 , discussionUrl :: DiscussionUrl
                                 , editor :: Editor
                                 , educationalAlignment :: EducationalAlignment
                                 , educationalUse :: EducationalUse
                                 , encoding :: Encoding
                                 , exampleOfWork :: ExampleOfWork
                                 , fileFormat :: FileFormat
                                 , genre :: Genre
                                 , hasPart :: HasPart
                                 , headline :: Headline
                                 , inLanguage :: InLanguage
                                 , interactionStatistic :: InteractionStatistic
                                 , interactivityType :: InteractivityType
                                 , isBasedOnUrl :: IsBasedOnUrl
                                 , isFamilyFriendly :: IsFamilyFriendly
                                 , isPartOf :: IsPartOf
                                 , keywords :: Keywords
                                 , learningResourceType :: LearningResourceType
                                 , license :: License
                                 , locationCreated :: LocationCreated
                                 , mainEntity :: MainEntity
                                 , mentions :: Mentions
                                 , offers :: Offers
                                 , position :: Position
                                 , producer :: Producer
                                 , provider :: Provider
                                 , publication :: Publication
                                 , publisher :: Publisher
                                 , publishingPrinciples :: PublishingPrinciples
                                 , recordedAt :: RecordedAt
                                 , releasedEvent :: ReleasedEvent
                                 , review :: Review
                                 , schemaVersion :: SchemaVersion
                                 , sourceOrganization :: SourceOrganization
                                 , text :: Text
                                 , thumbnailUrl :: ThumbnailUrl
                                 , timeRequired :: TimeRequired
                                 , translator :: Translator
                                 , typicalAgeRange :: TypicalAgeRange
                                 , version :: Version
                                 , video :: Video
                                 , workExample :: WorkExample
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData RadioEpisode where
  _label         = const "Radio Episode"
  _comment_plain = const "A radio episode which can be part of a series or season."
  _comment       = const "A radio episode which can be part of a series or season."
  _url           = const "http://schema.org/RadioEpisode"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Episode.Episode)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Episode.Episode)]