{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Rating where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AggregateRating

-- | A rating is an evaluation on a numeric scale, such as 1 to 5 stars.
--
--   [@id@] Rating
--
--   [@label@] Rating
--
--   [@comment@] A rating is an evaluation on a numeric scale, such as 1 to 5 stars.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@] @'AggregateRating'@
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Rating>
data Rating = Rating { bestRating :: BestRating
                     , ratingValue :: RatingValue
                     , worstRating :: WorstRating
                     , additionalType :: AdditionalType
                     , alternateName :: AlternateName
                     , description :: Description
                     , image :: Image
                     , mainEntityOfPage :: MainEntityOfPage
                     , name :: Name
                     , potentialAction :: PotentialAction
                     , sameAs :: SameAs
                     , url :: Url
                     }
              deriving (Show, Read, Eq, Typeable)

instance MetaData Rating where
  _label         = const "Rating"
  _comment_plain = const "A rating is an evaluation on a numeric scale, such as 1 to 5 stars."
  _comment       = const "A rating is an evaluation on a numeric scale, such as 1 to 5 stars."
  _url           = const "http://schema.org/Rating"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AggregateRating.AggregateRating)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]