{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Reservation where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BusReservation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EventReservation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.FlightReservation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.FoodEstablishmentReservation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LodgingReservation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RentalCarReservation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ReservationPackage
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TaxiReservation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TrainReservation

-- | Describes a reservation for travel, dining or an event. Some reservations require tickets.
--
--   [@id@] Reservation
--
--   [@label@] Reservation
--
--   [@comment@] Describes a reservation for travel, dining or an event. Some reservations require tickets.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@] @'BusReservation','EventReservation','FlightReservation','FoodEstablishmentReservation','LodgingReservation','RentalCarReservation','ReservationPackage','TaxiReservation','TrainReservation'@
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Reservation>
data Reservation = Reservation { bookingTime :: BookingTime
                               , broker :: Broker
                               , modifiedTime :: ModifiedTime
                               , priceCurrency :: PriceCurrency
                               , programMembershipUsed :: ProgramMembershipUsed
                               , provider :: Provider
                               , reservationFor :: ReservationFor
                               , reservationId :: ReservationId
                               , reservationStatus :: ReservationStatus
                               , reservedTicket :: ReservedTicket
                               , totalPrice :: TotalPrice
                               , underName :: UnderName
                               , additionalType :: AdditionalType
                               , alternateName :: AlternateName
                               , description :: Description
                               , image :: Image
                               , mainEntityOfPage :: MainEntityOfPage
                               , name :: Name
                               , potentialAction :: PotentialAction
                               , sameAs :: SameAs
                               , url :: Url
                               }
                   deriving (Show, Read, Eq, Typeable)

instance MetaData Reservation where
  _label         = const "Reservation"
  _comment_plain = const "Describes a reservation for travel, dining or an event. Some reservations require tickets."
  _comment       = const "Describes a reservation for travel, dining or an event. Some reservations require tickets."
  _url           = const "http://schema.org/Reservation"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BusReservation.BusReservation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EventReservation.EventReservation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.FlightReservation.FlightReservation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.FoodEstablishmentReservation.FoodEstablishmentReservation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LodgingReservation.LodgingReservation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RentalCarReservation.RentalCarReservation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ReservationPackage.ReservationPackage)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TaxiReservation.TaxiReservation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TrainReservation.TrainReservation)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]