{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ReservationPackage where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Reservation

-- | A group of multiple reservations with common values for all sub-reservations.
--
--   [@id@] ReservationPackage
--
--   [@label@] Reservation Package
--
--   [@comment@] A group of multiple reservations with common values for all sub-reservations.
--
--   [@ancestors@] @'Thing','Intangible','Reservation'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Reservation'@
--
--   [@url@] <http://schema.org/ReservationPackage>
data ReservationPackage = ReservationPackage { subReservation :: SubReservation
                                             , bookingTime :: BookingTime
                                             , broker :: Broker
                                             , modifiedTime :: ModifiedTime
                                             , priceCurrency :: PriceCurrency
                                             , programMembershipUsed :: ProgramMembershipUsed
                                             , provider :: Provider
                                             , reservationFor :: ReservationFor
                                             , reservationId :: ReservationId
                                             , reservationStatus :: ReservationStatus
                                             , reservedTicket :: ReservedTicket
                                             , totalPrice :: TotalPrice
                                             , underName :: UnderName
                                             , additionalType :: AdditionalType
                                             , alternateName :: AlternateName
                                             , description :: Description
                                             , image :: Image
                                             , mainEntityOfPage :: MainEntityOfPage
                                             , name :: Name
                                             , potentialAction :: PotentialAction
                                             , sameAs :: SameAs
                                             , url :: Url
                                             }
                          deriving (Show, Read, Eq, Typeable)

instance MetaData ReservationPackage where
  _label         = const "Reservation Package"
  _comment_plain = const "A group of multiple reservations with common values for all sub-reservations."
  _comment       = const "A group of multiple reservations with common values for all sub-reservations."
  _url           = const "http://schema.org/ReservationPackage"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Reservation.Reservation)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Reservation.Reservation)]