{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Residence where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ApartmentComplex
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.GatedResidenceCommunity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SingleFamilyResidence

-- | The place where a person lives.
--
--   [@id@] Residence
--
--   [@label@] Residence
--
--   [@comment@] The place where a person lives.
--
--   [@ancestors@] @'Thing','Place'@
--
--   [@subtypes@] @'ApartmentComplex','GatedResidenceCommunity','SingleFamilyResidence'@
--
--   [@supertypes@] @'Place'@
--
--   [@url@] <http://schema.org/Residence>
data Residence = Residence { additionalProperty :: AdditionalProperty
                           , address :: Address
                           , aggregateRating :: AggregateRating
                           , branchCode :: BranchCode
                           , containedInPlace :: ContainedInPlace
                           , containsPlace :: ContainsPlace
                           , event :: Event
                           , faxNumber :: FaxNumber
                           , geo :: Geo
                           , globalLocationNumber :: GlobalLocationNumber
                           , hasMap :: HasMap
                           , isicV4 :: IsicV4
                           , logo :: Logo
                           , openingHoursSpecification :: OpeningHoursSpecification
                           , photo :: Photo
                           , review :: Review
                           , telephone :: Telephone
                           , additionalType :: AdditionalType
                           , alternateName :: AlternateName
                           , description :: Description
                           , image :: Image
                           , mainEntityOfPage :: MainEntityOfPage
                           , name :: Name
                           , potentialAction :: PotentialAction
                           , sameAs :: SameAs
                           , url :: Url
                           }
                 deriving (Show, Read, Eq, Typeable)

instance MetaData Residence where
  _label         = const "Residence"
  _comment_plain = const "The place where a person lives."
  _comment       = const "The place where a person lives."
  _url           = const "http://schema.org/Residence"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ApartmentComplex.ApartmentComplex)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.GatedResidenceCommunity.GatedResidenceCommunity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SingleFamilyResidence.SingleFamilyResidence)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)]