{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ReturnAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TransferAction

-- | The act of returning to the origin that which was previously received (concrete objects) or taken (ownership).
--
--   [@id@] ReturnAction
--
--   [@label@] Return Action
--
--   [@comment@] The act of returning to the origin that which was previously received (concrete objects) or taken (ownership).
--
--   [@ancestors@] @'Thing','Action','TransferAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'TransferAction'@
--
--   [@url@] <http://schema.org/ReturnAction>
data ReturnAction = ReturnAction { recipient :: Recipient
                                 , fromLocation :: FromLocation
                                 , toLocation :: ToLocation
                                 , actionStatus :: ActionStatus
                                 , agent :: Agent
                                 , endTime :: EndTime
                                 , error :: Error
                                 , instrument :: Instrument
                                 , location :: Location
                                 , object :: Object
                                 , participant :: Participant
                                 , result :: Result
                                 , startTime :: StartTime
                                 , target :: Target
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData ReturnAction where
  _label         = const "Return Action"
  _comment_plain = const "The act of returning to the origin that which was previously received (concrete objects) or taken (ownership)."
  _comment       = const "The act of returning to the origin that which was previously received (concrete objects) or taken (ownership)."
  _url           = const "http://schema.org/ReturnAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TransferAction.TransferAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.TransferAction.TransferAction)]