{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Service where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BroadcastService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CableOrSatelliteService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.GovernmentService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Taxi
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TaxiService

-- | A service provided by an organization, e.g. delivery service, print services, etc.
--
--   [@id@] Service
--
--   [@label@] Service
--
--   [@comment@] A service provided by an organization, e.g. delivery service, print services, etc.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@] @'BroadcastService','CableOrSatelliteService','GovernmentService','Taxi','TaxiService'@
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Service>
data Service = Service { aggregateRating :: AggregateRating
                       , areaServed :: AreaServed
                       , availableChannel :: AvailableChannel
                       , award :: Award
                       , category :: Category
                       , hasOfferCatalog :: HasOfferCatalog
                       , hoursAvailable :: HoursAvailable
                       , offers :: Offers
                       , provider :: Provider
                       , providerMobility :: ProviderMobility
                       , review :: Review
                       , serviceOutput :: ServiceOutput
                       , serviceType :: ServiceType
                       , additionalType :: AdditionalType
                       , alternateName :: AlternateName
                       , description :: Description
                       , image :: Image
                       , mainEntityOfPage :: MainEntityOfPage
                       , name :: Name
                       , potentialAction :: PotentialAction
                       , sameAs :: SameAs
                       , url :: Url
                       }
               deriving (Show, Read, Eq, Typeable)

instance MetaData Service where
  _label         = const "Service"
  _comment_plain = const "A service provided by an organization, e.g. delivery service, print services, etc."
  _comment       = const "A service provided by an organization, e.g. delivery service, print services, etc."
  _url           = const "http://schema.org/Service"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BroadcastService.BroadcastService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CableOrSatelliteService.CableOrSatelliteService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.GovernmentService.GovernmentService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Taxi.Taxi)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TaxiService.TaxiService)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]