{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ServiceChannel where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | A means for accessing a service, e.g. a government office location, web site, or phone number.
--
--   [@id@] ServiceChannel
--
--   [@label@] Service Channel
--
--   [@comment@] A means for accessing a service, e.g. a government office location, web site, or phone number.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/ServiceChannel>
data ServiceChannel = ServiceChannel { availableLanguage :: AvailableLanguage
                                     , processingTime :: ProcessingTime
                                     , providesService :: ProvidesService
                                     , serviceLocation :: ServiceLocation
                                     , servicePhone :: ServicePhone
                                     , servicePostalAddress :: ServicePostalAddress
                                     , serviceSmsNumber :: ServiceSmsNumber
                                     , serviceUrl :: ServiceUrl
                                     , additionalType :: AdditionalType
                                     , alternateName :: AlternateName
                                     , description :: Description
                                     , image :: Image
                                     , mainEntityOfPage :: MainEntityOfPage
                                     , name :: Name
                                     , potentialAction :: PotentialAction
                                     , sameAs :: SameAs
                                     , url :: Url
                                     }
                      deriving (Show, Read, Eq, Typeable)

instance MetaData ServiceChannel where
  _label         = const "Service Channel"
  _comment_plain = const "A means for accessing a service, e.g. a government office location, web site, or phone number."
  _comment       = const "A means for accessing a service, e.g. a government office location, web site, or phone number."
  _url           = const "http://schema.org/ServiceChannel"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]