{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.SportsActivityLocation where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type hiding (SportsActivityLocation)
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SportsActivityLocation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BowlingAlley
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ExerciseGym
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.GolfCourse
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.HealthClub
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PublicSwimmingPool
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SkiResort
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SportsClub
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StadiumOrArena
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TennisComplex

-- | A sports location, such as a playing field.
--
--   [@id@] SportsActivityLocation
--
--   [@label@] Sports Activity Location
--
--   [@comment@] A sports location, such as a playing field.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','SportsActivityLocation','Thing','Place','LocalBusiness'@
--
--   [@subtypes@] @'BowlingAlley','ExerciseGym','GolfCourse','HealthClub','PublicSwimmingPool','SkiResort','SportsClub','StadiumOrArena','TennisComplex'@
--
--   [@supertypes@] @'LocalBusiness'@
--
--   [@url@] <http://schema.org/SportsActivityLocation>
data SportsActivityLocation = SportsActivityLocation { branchCode :: BranchCode
                                                     , currenciesAccepted :: CurrenciesAccepted
                                                     , openingHours :: OpeningHours
                                                     , paymentAccepted :: PaymentAccepted
                                                     , priceRange :: PriceRange
                                                     , additionalProperty :: AdditionalProperty
                                                     , address :: Address
                                                     , aggregateRating :: AggregateRating
                                                     , containedInPlace :: ContainedInPlace
                                                     , containsPlace :: ContainsPlace
                                                     , event :: Event
                                                     , faxNumber :: FaxNumber
                                                     , geo :: Geo
                                                     , globalLocationNumber :: GlobalLocationNumber
                                                     , hasMap :: HasMap
                                                     , isicV4 :: IsicV4
                                                     , logo :: Logo
                                                     , openingHoursSpecification :: OpeningHoursSpecification
                                                     , photo :: Photo
                                                     , review :: Review
                                                     , telephone :: Telephone
                                                     , alumni :: Alumni
                                                     , areaServed :: AreaServed
                                                     , award :: Award
                                                     , brand :: Brand
                                                     , contactPoint :: ContactPoint
                                                     , department :: Department
                                                     , dissolutionDate :: DissolutionDate
                                                     , duns :: Duns
                                                     , email :: Email
                                                     , employee :: Employee
                                                     , founder :: Founder
                                                     , foundingDate :: FoundingDate
                                                     , foundingLocation :: FoundingLocation
                                                     , hasOfferCatalog :: HasOfferCatalog
                                                     , hasPOS :: HasPOS
                                                     , legalName :: LegalName
                                                     , location :: Location
                                                     , makesOffer :: MakesOffer
                                                     , member :: Member
                                                     , memberOf :: MemberOf
                                                     , naics :: Naics
                                                     , numberOfEmployees :: NumberOfEmployees
                                                     , owns :: Owns
                                                     , parentOrganization :: ParentOrganization
                                                     , seeks :: Seeks
                                                     , subOrganization :: SubOrganization
                                                     , taxID :: TaxID
                                                     , vatID :: VatID
                                                     , additionalType :: AdditionalType
                                                     , alternateName :: AlternateName
                                                     , description :: Description
                                                     , image :: Image
                                                     , mainEntityOfPage :: MainEntityOfPage
                                                     , name :: Name
                                                     , potentialAction :: PotentialAction
                                                     , sameAs :: SameAs
                                                     , url :: Url
                                                     }
                              deriving (Show, Read, Eq, Typeable)

instance MetaData SportsActivityLocation where
  _label         = const "Sports Activity Location"
  _comment_plain = const "A sports location, such as a playing field."
  _comment       = const "A sports location, such as a playing field."
  _url           = const "http://schema.org/SportsActivityLocation"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SportsActivityLocation.SportsActivityLocation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BowlingAlley.BowlingAlley)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ExerciseGym.ExerciseGym)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.GolfCourse.GolfCourse)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.HealthClub.HealthClub)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PublicSwimmingPool.PublicSwimmingPool)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SkiResort.SkiResort)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SportsClub.SportsClub)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StadiumOrArena.StadiumOrArena)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TennisComplex.TennisComplex)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)]