{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.State where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AdministrativeArea

-- | A state or province of a country.
--
--   [@id@] State
--
--   [@label@] State
--
--   [@comment@] A state or province of a country.
--
--   [@ancestors@] @'Thing','Place','AdministrativeArea'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'AdministrativeArea'@
--
--   [@url@] <http://schema.org/State>
data State = State { additionalProperty :: AdditionalProperty
                   , address :: Address
                   , aggregateRating :: AggregateRating
                   , branchCode :: BranchCode
                   , containedInPlace :: ContainedInPlace
                   , containsPlace :: ContainsPlace
                   , event :: Event
                   , faxNumber :: FaxNumber
                   , geo :: Geo
                   , globalLocationNumber :: GlobalLocationNumber
                   , hasMap :: HasMap
                   , isicV4 :: IsicV4
                   , logo :: Logo
                   , openingHoursSpecification :: OpeningHoursSpecification
                   , photo :: Photo
                   , review :: Review
                   , telephone :: Telephone
                   , additionalType :: AdditionalType
                   , alternateName :: AlternateName
                   , description :: Description
                   , image :: Image
                   , mainEntityOfPage :: MainEntityOfPage
                   , name :: Name
                   , potentialAction :: PotentialAction
                   , sameAs :: SameAs
                   , url :: Url
                   }
             deriving (Show, Read, Eq, Typeable)

instance MetaData State where
  _label         = const "State"
  _comment_plain = const "A state or province of a country."
  _comment       = const "A state or province of a country."
  _url           = const "http://schema.org/State"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AdministrativeArea.AdministrativeArea)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AdministrativeArea.AdministrativeArea)]