{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.TrainTrip where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | A trip on a commercial train line.
--
--   [@id@] TrainTrip
--
--   [@label@] Train Trip
--
--   [@comment@] A trip on a commercial train line.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/TrainTrip>
data TrainTrip = TrainTrip { arrivalPlatform :: ArrivalPlatform
                           , arrivalStation :: ArrivalStation
                           , arrivalTime :: ArrivalTime
                           , departurePlatform :: DeparturePlatform
                           , departureStation :: DepartureStation
                           , departureTime :: DepartureTime
                           , provider :: Provider
                           , trainName :: TrainName
                           , trainNumber :: TrainNumber
                           , additionalType :: AdditionalType
                           , alternateName :: AlternateName
                           , description :: Description
                           , image :: Image
                           , mainEntityOfPage :: MainEntityOfPage
                           , name :: Name
                           , potentialAction :: PotentialAction
                           , sameAs :: SameAs
                           , url :: Url
                           }
                 deriving (Show, Read, Eq, Typeable)

instance MetaData TrainTrip where
  _label         = const "Train Trip"
  _comment_plain = const "A trip on a commercial train line."
  _comment       = const "A trip on a commercial train line."
  _url           = const "http://schema.org/TrainTrip"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]