{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.TypeAndQuantityNode where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue

-- | A structured value indicating the quantity, unit of measurement, and business function of goods included in a bundle offer.
--
--   [@id@] TypeAndQuantityNode
--
--   [@label@] Type And Quantity Node
--
--   [@comment@] A structured value indicating the quantity, unit of measurement, and business function of goods included in a bundle offer.
--
--   [@ancestors@] @'Thing','Intangible','StructuredValue'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'StructuredValue'@
--
--   [@url@] <http://schema.org/TypeAndQuantityNode>
data TypeAndQuantityNode = TypeAndQuantityNode { amountOfThisGood :: AmountOfThisGood
                                               , businessFunction :: BusinessFunction
                                               , typeOfGood :: TypeOfGood
                                               , unitCode :: UnitCode
                                               , unitText :: UnitText
                                               , additionalType :: AdditionalType
                                               , alternateName :: AlternateName
                                               , description :: Description
                                               , image :: Image
                                               , mainEntityOfPage :: MainEntityOfPage
                                               , name :: Name
                                               , potentialAction :: PotentialAction
                                               , sameAs :: SameAs
                                               , url :: Url
                                               }
                           deriving (Show, Read, Eq, Typeable)

instance MetaData TypeAndQuantityNode where
  _label         = const "Type And Quantity Node"
  _comment_plain = const "A structured value indicating the quantity, unit of measurement, and business function of goods included in a bundle offer."
  _comment       = const "A structured value indicating the quantity, unit of measurement, and business function of goods included in a bundle offer."
  _url           = const "http://schema.org/TypeAndQuantityNode"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]